@@ -11,7 +11,6 @@
 #include <QDebug>
 #include <QJsonArray>
 #include <QJsonObject>
-#include <QObject>
 #include <QSharedData>
 
 using namespace KUserFeedback::Console;
@@ -135,3 +134,5 @@ QVector<SchemaEntry> SchemaEntry::fromJson(const QJsonArray &array)
 
     return res;
 }
+
+#include "moc_schemaentry.cpp"
