@@ -29,16 +29,11 @@
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QSettings>
-#include <QUrl>
 #include <QUuid>
 
 #include <algorithm>
 #include <numeric>
 
-namespace KUserFeedback {
-Q_LOGGING_CATEGORY(Log, "org.kde.UserFeedback", QtInfoMsg)
-}
-
 using namespace KUserFeedback;
 
 ProviderPrivate::ProviderPrivate(Provider *qq)
@@ -131,6 +126,18 @@ void ProviderPrivate::load()
 
     s->endGroup();
 
+    // ensure consistent times if settings is corrupt, to avoid overflows later in the code
+    const auto now = QDateTime::currentDateTime();
+    if (now < lastSubmitTime) {
+        lastSubmitTime = now;
+    }
+    if (now < lastSurveyTime) {
+        lastSurveyTime = now;
+    }
+    if (now < lastEncouragementTime) {
+        lastEncouragementTime = now;
+    }
+
     foreach (auto source, dataSources) {
         s->beginGroup(QStringLiteral("Source-") + source->id());
         source->load(s.get());
@@ -733,7 +740,7 @@ QString Provider::describeDataSources() const
     Q_ASSERT(modeEnumIdx >= 0);
 
     const auto modeEnum = mo.enumerator(modeEnumIdx);
-    for (auto source : d->dataSources) {
+    for (auto source : qAsConst(d->dataSources)) {
         ret += QString::fromUtf8(modeEnum.valueToKey(source->telemetryMode())) + QStringLiteral(": ") + source->name() + QLatin1Char('\n');
     }
     return ret;
